# 环境要求

- PHP 5.3.9+
  - php-mcrypt
  - php-pdo
  - php-pdo-mysql
  - php-mbstring
- Composer (MAC下`brew install composer`或去官网[composer](http://getcomposer.org))
- Apache/Nginx
- Mysql 5.1+
- Git

# 安装

> 如果是cPannel等虚拟主机，需要在相应界面进行修改，不需要操作命令行

## 获取源代码

```
git clone git@github.com:Trimidea/inews.git
cd 程序根目录
composer install(composer设置好了才能执行这一步)
```

## 配置环境

```
export PAGON_ENV=production
```

## 修改配置

```
cd 程序根目录
cp config/develop.php config/production.php
vim config/production.php
# 0.1.9起，支持通过env文件指定配置
echo "production" > config/env
```

> 具体说明可以参照 [配置说明](./02-Setup.md)
> 正式环境需要删除debug配置

## 初始化

```
./bin/task db:init
```

> 用来初始化数据库  
> 这步出问题：  
> 首先检查你的mysql相关的东西都有没有装好  
> 其次看看你的mysql有没有正常启动  
> 最后看看你production.php文件里数据库的root用户密码有没有写对  

## 升级数据库

```
./bin/task db:migrate
```

> 初始化和升级都需要执行，确保数据库是最新的版本

## 定时任务

```
[root@localhost]#: crontab -e
```
> 把下面文字加到定时任务里。

```
*/10 * * * * 程序根目录/bin/task job:point
```

> 用来计算积分和排名


## 配置主机

### 如果是Apache

```
<VirtualHost *:80>
    DocumentRoot "程序根目录" #比如/usr/local/src/inews
    ServerName example.com
    SetEnv PAGON_ENV production

    <Directory 程序根目录>
        Options FollowSymLinks
        AllowOverride All
        Order deny,allow
        Allow from all
    </Directory>
</VirtualHost>
```

### 如果是Nginx+FPM

```
server {
    listen 80;

	root 程序根目录; #比如/usr/local/src/inews
	index index.php index.html index.htm;

	server_name example.com;

	location / {
		try_files $uri $uri/ /index.php?$query_string;
	}

	location ~* \.(?:ico|css|js|gif|jpe?g|png)$ {
		expires 30d;
 		add_header Pragma public;
		add_header Cache-Control "public";
	}

	location ~ \.php$ {
	    # PHP的支持根据自己的情况进行配置
	    # 9000是FPM的默认端口
		fastcgi_pass 127.0.0.1:9000;
		include fastcgi_params;
	}
}
```

FPM配置添加环境变量

```
env[PAGON_ENV] = production
```

问题
-----

Q: Windows下可否安装？
> Window下没做测试，理论上可以安装成功，但可能会存在一定问题

Q: 如果页面没有任何输出怎么办？
> 配置文件中开启Debug模式，添加`"debug" => true`，检查问题，无法解决反馈给我

Q: 页面输出不完整或者接口响应失败?
> 大部分情况是UTF-8 BOM造成，不要使用记事本编辑，如果造成，建议拷贝出内容使用其它编辑器编辑
